==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_external/l10n/ru.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Ошибка получения токенов запроса. Проверьте корректность ключа и секрета приложения.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Ошибка получения токенов доступа. Проверьте корректность ключа и секрета приложения.",
    "Please provide a valid app key and secret." : "Пожалуйста укажите корректные ключ и секрет приложения.",
    "Step 1 failed. Exception: %s" : "Шаг 1 неудачен. Исключение: %s",
    "Step 2 failed. Exception: %s" : "Шаг 2 неудачен. Исключение: %s",
    "External storage" : "Внешнее хранилище",
    "Storage with id \"%i\" not found" : "Хранилище с идентификатором \"%i\" не найдено",
    "Invalid backend or authentication mechanism class" : "Некорректный механизм авторизации или бэкенд",
    "Invalid mount point" : "Неправильная точка входа",
    "Objectstore forbidden" : "Хранение объектов запрещено",
    "Invalid storage backend \"%s\"" : "Неверный бэкенд хранилища \"%s\"",
    "Not permitted to use backend \"%s\"" : "Не допускается использование бэкенда \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Не допускается использование механизма авторизации \"%s\"",
    "Unsatisfied backend parameters" : "Недопустимые настройки бэкенда",
    "Unsatisfied authentication mechanism parameters" : "Недопустимые настройки механизма авторизации",
    "Insufficient data: %s" : "Недостаточно данных: %s",
    "%s" : "%s",
    "Storage with id \"%i\" is not user editable" : "Пользователь не может редактировать хранилище \"%i\"",
    "Personal" : "Личное",
    "System" : "Система",
    "Grant access" : "Предоставить доступ",
    "Access granted" : "Доступ предоставлен",
    "Error configuring OAuth1" : "Ошибка настройки OAuth1",
    "Error configuring OAuth2" : "Ошибка настройки OAuth2",
    "Generate keys" : "Создать ключи",
    "Error generating key pair" : "Ошибка создания ключевой пары",
    "Enable encryption" : "Включить шифрование",
    "Enable previews" : "Включить предпросмотр",
    "Enable sharing" : "Включить общий доступ",
    "Check for changes" : "Проверять изменения",
    "Never" : "Никогда",
    "Once every direct access" : "Один раз при прямом доступе",
    "All users. Type to select user or group." : "Все пользователи. Введите имя пользователя или группы.",
    "(group)" : "(группа)",
    "Admin defined" : "Админ определен",
    "Saved" : "Сохранено",
    "Empty response from the server" : "Пустой ответ от сервера",
    "Couldn't access. Please logout and login to activate this mount point" : "Не удалось получить доступ. Пожалуйста, выйти и войдите чтобы активировать эту точку монтирования",
    "Couldn't get the information from the ownCloud server: {code} {type}" : "Не удалось получить информацию от сервера OwnCloud: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Не удалось получить список внешних точек монтирования: {type}",
    "There was an error with message: " : "Обнаружена ошибка в сообщении:",
    "External mount error" : "Ошибка внешнего монтажа",
    "external-storage" : "внешнее-хранилище",
    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "Не удалось получить список окон сетевого диска точки монтирования: пустой ответ от сервера",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Некоторые из настроенных внешних точек монтирования не подключены. Для получения дополнительной информации, пожалуйста нажмите на красную строку (ы)",
    "Please enter the credentials for the {mount} mount" : "Пожалуйста укажите учетные данные для {mount}",
    "Username" : "Имя пользователя",
    "Password" : "Пароль",
    "Credentials saved" : "Учетные данные сохранены",
    "Credentials saving failed" : "Ошибка сохранения учетных данных",
    "Credentials required" : "Требуются учетные данные",
    "Save" : "Сохранить",
    "Access key" : "Ключ доступа",
    "Secret key" : "Секретный ключ",
    "Builtin" : "Встроенный",
    "None" : "Отсутствует",
    "OAuth1" : "OAuth1",
    "App key" : "Ключ приложения",
    "App secret" : "Секретный ключ ",
    "OAuth2" : "OAuth2",
    "Client ID" : "Идентификатор клиента",
    "Client secret" : "Клиентский ключ ",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Имя арендатора",
    "Identity endpoint URL" : "Удостоверение конечной точки URL",
    "Rackspace" : "Rackspace",
    "API key" : "Ключ API",
    "Username and password" : "Имя пользователя и пароль",
    "Log-in credentials, save in session" : "Учетные данные, хранить в сессии",
    "RSA public key" : "Открытый ключ RSA",
    "Public key" : "Открытый ключ",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Корзина",
    "Hostname" : "Имя хоста",
    "Port" : "Порт",
    "Region" : "Область",
    "Enable SSL" : "Включить SSL",
    "Enable Path Style" : "Включить стиль пути",
    "WebDAV" : "WebDAV",
    "URL" : "Ссылка",
    "Remote subfolder" : "Удаленный подкаталог",
    "Secure https://" : "Безопасный https://",
    "Dropbox" : "Dropbox",
    "FTP" : "FTP",
    "Host" : "Сервер",
    "Secure ftps://" : "Защищённый ftps://",
    "Google Drive" : "Google Drive",
    "Local" : "Локально",
    "Location" : "Местоположение",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Root" : "Корневой каталог",
    "SFTP with secret key login" : "SFTP с помощью секретного ключа",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Общий доступ",
    "Domain" : "Домен",
    "SMB / CIFS using OC login" : "SMB / CIFS с ипользованием логина OC",
    "Username as share" : "Имя пользователя в качестве имени общего ресурса",
    "OpenStack Object Storage" : "Хранилище объектов OpenStack",
    "Service name" : "Название сервиса",
    "Request timeout (seconds)" : "Таймаут запроса (секунды)",
    "<b>Note:</b> " : "<b>Примечание:</b> ",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Примечание:</b> Поддержка cURL в PHP не включена или не установлена. Монтирование %s невозможно. Обратитесь к вашему системному администратору.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Примечание:</b> Поддержка FTP в PHP не включена или не установлена. Монтирование %s невозможно. Пожалуйста, обратитесь к системному администратору.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Примечание:</b> \"%s\" не установлен. Монтирование %s невозможно. Пожалуйста, обратитесь к системному администратору.",
    "No external storage configured" : "Нет внешних хранилищ",
    "You can add external storages in the personal settings" : "Вы можете добавить внешние накопители в личных настройках",
    "Name" : "Имя",
    "Storage type" : "Тип хранилища",
    "Scope" : "Область",
    "External Storage" : "Внешнее хранилище",
    "Folder name" : "Имя каталога",
    "Authentication" : "Авторизация",
    "Configuration" : "Конфигурация",
    "Available for" : "Доступно для",
    "Add storage" : "Добавить хранилище",
    "Advanced settings" : "Расширенные настройки",
    "Delete" : "Удалить",
    "Allow users to mount external storage" : "Разрешить пользователями монтировать внешние накопители",
    "Allow users to mount the following external storage" : "Разрешить пользователям монтировать следующие сервисы хранения данных"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> owncloud-9.0.2-2-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_external/l10n/ru.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Ошибка получения токенов запроса. Проверьте корректность ключа и секрета приложения.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Ошибка получения токенов доступа. Проверьте корректность ключа и секрета приложения.",
    "Please provide a valid app key and secret." : "Пожалуйста укажите корректные ключ и секрет приложения.",
    "Step 1 failed. Exception: %s" : "Шаг 1 неудачен. Исключение: %s",
    "Step 2 failed. Exception: %s" : "Шаг 2 неудачен. Исключение: %s",
    "External storage" : "Внешнее хранилище",
    "Storage with id \"%i\" not found" : "Хранилище с идентификатором \"%i\" не найдено",
    "Invalid backend or authentication mechanism class" : "Некорректный механизм авторизации или бэкенд",
    "Invalid mount point" : "Неправильная точка входа",
    "Objectstore forbidden" : "Хранение объектов запрещено",
    "Invalid storage backend \"%s\"" : "Неверный бэкенд хранилища \"%s\"",
    "Not permitted to use backend \"%s\"" : "Не допускается использование бэкенда \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Не допускается использование механизма авторизации \"%s\"",
    "Unsatisfied backend parameters" : "Недопустимые настройки бэкенда",
    "Unsatisfied authentication mechanism parameters" : "Недопустимые настройки механизма авторизации",
    "Insufficient data: %s" : "Недостаточно данных: %s",
    "%s" : "%s",
    "Storage with id \"%i\" is not user editable" : "Пользователь не может редактировать хранилище \"%i\"",
    "Personal" : "Личное",
    "System" : "Система",
    "Grant access" : "Предоставить доступ",
    "Access granted" : "Доступ предоставлен",
    "Error configuring OAuth1" : "Ошибка настройки OAuth1",
    "Error configuring OAuth2" : "Ошибка настройки OAuth2",
    "Generate keys" : "Создать ключи",
    "Error generating key pair" : "Ошибка создания ключевой пары",
    "Enable encryption" : "Включить шифрование",
    "Enable previews" : "Включить предпросмотр",
    "Enable sharing" : "Включить общий доступ",
    "Check for changes" : "Проверять изменения",
    "Never" : "Никогда",
    "Once every direct access" : "Один раз при прямом доступе",
    "All users. Type to select user or group." : "Все пользователи. Введите имя пользователя или группы.",
    "(group)" : "(группа)",
    "Admin defined" : "Админ определен",
    "Saved" : "Сохранено",
    "Empty response from the server" : "Пустой ответ от сервера",
    "Couldn't access. Please logout and login to activate this mount point" : "Не удалось получить доступ. Пожалуйста, выйти и войдите чтобы активировать эту точку монтирования",
    "Couldn't get the information from the ownCloud server: {code} {type}" : "Не удалось получить информацию от сервера OwnCloud: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Не удалось получить список внешних точек монтирования: {type}",
    "There was an error with message: " : "Обнаружена ошибка в сообщении:",
    "External mount error" : "Ошибка внешнего монтажа",
    "external-storage" : "внешнее-хранилище",
    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "Не удалось получить список окон сетевого диска точки монтирования: пустой ответ от сервера",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Некоторые из настроенных внешних точек монтирования не подключены. Для получения дополнительной информации, пожалуйста нажмите на красную строку (ы)",
    "Please enter the credentials for the {mount} mount" : "Пожалуйста укажите учетные данные для {mount}",
    "Username" : "Имя пользователя",
    "Password" : "Пароль",
    "Credentials saved" : "Учетные данные сохранены",
    "Credentials saving failed" : "Ошибка сохранения учетных данных",
    "Credentials required" : "Требуются учетные данные",
    "Save" : "Сохранить",
    "Access key" : "Ключ доступа",
    "Secret key" : "Секретный ключ",
    "Builtin" : "Встроенный",
    "None" : "Отсутствует",
    "OAuth1" : "OAuth1",
    "App key" : "Ключ приложения",
    "App secret" : "Секретный ключ ",
    "OAuth2" : "OAuth2",
    "Client ID" : "Идентификатор клиента",
    "Client secret" : "Клиентский ключ ",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Имя арендатора",
    "Identity endpoint URL" : "Удостоверение конечной точки URL",
    "Rackspace" : "Rackspace",
    "API key" : "Ключ API",
    "Username and password" : "Имя пользователя и пароль",
    "Log-in credentials, save in session" : "Учетные данные, хранить в сессии",
    "RSA public key" : "Открытый ключ RSA",
    "Public key" : "Открытый ключ",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Корзина",
    "Hostname" : "Имя хоста",
    "Port" : "Порт",
    "Region" : "Область",
    "Enable SSL" : "Включить SSL",
    "Enable Path Style" : "Включить стиль пути",
    "WebDAV" : "WebDAV",
    "URL" : "Ссылка",
    "Remote subfolder" : "Удаленный подкаталог",
    "Secure https://" : "Безопасный https://",
    "Dropbox" : "Dropbox",
    "FTP" : "FTP",
    "Host" : "Сервер",
    "Secure ftps://" : "Защищённый ftps://",
    "Google Drive" : "Google Drive",
    "Local" : "Локально",
    "Location" : "Местоположение",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Root" : "Корневой каталог",
    "SFTP with secret key login" : "SFTP с помощью секретного ключа",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Общий доступ",
    "Domain" : "Домен",
    "SMB / CIFS using OC login" : "SMB / CIFS с ипользованием логина OC",
    "Username as share" : "Имя пользователя в качестве имени общего ресурса",
    "OpenStack Object Storage" : "Хранилище объектов OpenStack",
    "Service name" : "Название сервиса",
    "Request timeout (seconds)" : "Таймаут запроса (секунды)",
    "<b>Note:</b> " : "<b>Примечание:</b> ",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Примечание:</b> Поддержка cURL в PHP не включена или не установлена. Монтирование %s невозможно. Обратитесь к вашему системному администратору.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Примечание:</b> Поддержка FTP в PHP не включена или не установлена. Монтирование %s невозможно. Пожалуйста, обратитесь к системному администратору.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Примечание:</b> \"%s\" не установлен. Монтирование %s невозможно. Пожалуйста, обратитесь к системному администратору.",
    "No external storage configured" : "Нет внешних хранилищ",
    "You can add external storages in the personal settings" : "Вы можете добавить внешние накопители в личных настройках",
    "Name" : "Имя",
    "Storage type" : "Тип хранилища",
    "Scope" : "Область",
    "External Storage" : "Внешнее хранилище",
    "Folder name" : "Имя каталога",
    "Authentication" : "Авторизация",
    "Configuration" : "Конфигурация",
    "Available for" : "Доступно для",
    "Add storage" : "Добавить хранилище",
    "Advanced settings" : "Расширенные настройки",
    "Delete" : "Удалить",
    "Allow users to mount external storage" : "Разрешить пользователями монтировать внешние накопители",
    "Allow users to mount the following external storage" : "Разрешить пользователям монтировать следующие сервисы хранения данных",
    "SMB / CIFS" : "SMB / CIFS",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Некоторые из настроенных внешних точек монтирования не подключены. Для получения дополнительной информации, пожалуйста нажмите на красную строку (ы)"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
